<?php
/**
 * CSS related hooks.
 *
 * This file contains hook functions which are related to CSS.
 *
 * @package Trade_Line
 */

if ( ! function_exists( 'trade_line_trigger_custom_css_action' ) ) :

	/**
	 * Do action theme custom CSS.
	 *
	 * @since 1.0.0
	 */
	function trade_line_trigger_custom_css_action() {

		/**
		 * Hook - trade_line_action_theme_custom_css.
		 *
		 * @hooked trade_line_add_option_custom_css - 99
		 */
		do_action( 'trade_line_action_theme_custom_css' );

	}

endif;

add_action( 'wp_head', 'trade_line_trigger_custom_css_action', 99 );

if ( ! function_exists( 'trade_line_add_option_custom_css' ) ) :

	/**
	 * Add custom CSS.
	 *
	 * @since 1.0.0
	 */
	function trade_line_add_option_custom_css() {

		$custom_css = trade_line_get_option( 'custom_css' );
		$output = '';
		if ( ! empty( $custom_css ) ) {
			$output = "\n" . '<style type="text/css">' . "\n";
			$output .= $custom_css;
			$output .= "\n" . '</style>' . "\n" ;
		}
		echo $output;

	}

endif;

add_action( 'trade_line_action_theme_custom_css', 'trade_line_add_option_custom_css', 99 );

if ( ! function_exists( 'trade_line_add_theme_custom_font_css' ) ) :

	/**
	 * Inject theme custom font CSS.
	 *
	 * @since 1.0.0
	 */
	function trade_line_add_theme_custom_font_css() {

		$custom_css = '';

		$font_settings = trade_line_get_font_family_theme_settings_options();

		$required_fonts = array();

		if ( ! empty( $font_settings ) ) {
			foreach ( $font_settings as $key => $val ) {
				$option_value = trade_line_get_option( $key );
				if ( ! empty( $option_value ) && $val['default'] !== $option_value ) {
					$required_fonts[ $key ] = $option_value;
				}
			}
		}
		if ( empty( $required_fonts ) ) {
			// We do not need extra CSS.
			return;
		}

		foreach ( $required_fonts as $key => $font ) {

			$family = trade_line_get_font_family_from_key( $font );

			if ( ! empty( $family ) ) {

				switch ( $key ) {
					case 'font_site_default':
						$custom_css .= 'body{font-family:' . $family . '}' . "\n";
					break;

					case 'font_site_title':
						$custom_css .= '.site-title{font-family:' . $family . '}' . "\n";
					break;

					case 'font_site_tagline':
						$custom_css .= '.site-description{font-family:' . $family . '}' . "\n";
					break;

					case 'font_heading_tags':
						$custom_css .= 'h1,h2,h3,h4,h5,h6{font-family:' . $family . '}' . "\n";
					break;

					case 'font_content_title':
						$custom_css .= '.entry-header .entry-title{font-family:' . $family . '}' . "\n";
					break;

					case 'font_content_body':
						$custom_css .= '#content{font-family:' . $family . '}' . "\n";
					break;

					case 'font_navigation':
						$custom_css .= '#site-navigation ul li a{font-family:' . $family . '}' . "\n";
					break;

					default:
					break;
				}
			}
		}

		// Render style.
		if ( ! empty( $custom_css ) ) {
			echo '<style type="text/css">';
			echo $custom_css;
			echo '</style>';
		}

	}

endif;

add_action( 'trade_line_action_theme_custom_css', 'trade_line_add_theme_custom_font_css' );


if ( ! function_exists( 'trade_line_add_theme_custom_color_css' ) ) :

	/**
	 * Inject theme custom color CSS.
	 *
	 * @since 1.0.0
	 */
	function trade_line_add_theme_custom_color_css() {

		$custom_css = '';

		$color_settings = trade_line_get_color_theme_settings_options();

		$default = trade_line_get_default_colors();

		$required_colors = array();

		if ( ! empty( $color_settings ) ) {
		  foreach ($color_settings as $key => $val ) {
		    $option_value = trade_line_get_option( $key );
		    if ( ! empty( $option_value ) && $default[$key] != $option_value ) {
		      $required_colors[ $key ] = $option_value;
		    }
		  }
		}
		if ( empty( $required_colors ) ) {
		  // We do not need extra CSS.
		  return;
		}

		foreach ( $required_colors as $key => $color ) {

			switch ( $key ){

				// Basic.
				case 'color_basic_background':
				$custom_css .= 'body.custom-background #page,body #page{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_basic_text':
				  $custom_css .= 'body{color:' . $color . '}' . "\n";
				  break;
				case 'color_basic_link':
				  $custom_css .= 'a,a:visited{color:' . $color . '}' . "\n";
				  break;
				case 'color_basic_link_hover':
				  $custom_css .= 'a:hover{color:' . $color . '}' . "\n";
				  break;
				case 'color_basic_heading':
				  $custom_css .= 'h1,h2,h3,h4,h5,h6{color:' . $color . '}' . "\n";
				  break;
				case 'color_basic_button_text':
				  $custom_css .= '#infinite-handle span,.search-box > a,a.button,.search-form .search-submit,.comment-reply-link,a.cta-button-primary,button, input[type="button"], input[type="reset"], input[type="submit"],#infinite-handle span button, #infinite-handle span button{color:' . $color . '}' . "\n";
				  $custom_css .= '.woocommerce #respond input#submit.alt, .woocommerce a.button.alt, .woocommerce button.button.alt, .woocommerce input.button.alt, .woocommerce #respond input#submit, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button{color:' . $color . '}' . "\n";
				  break;
				case 'color_basic_button_text_hover':
				  $custom_css .= '#infinite-handle span:hover.search-box > a:hover,a.button:hover,.search-form .search-submit:hover,a.cta-button-primary:hover,.comment-reply-link:hover,button:hover, input[type="button"]:hover, input[type="reset"]:hover, input[type="submit"]:hover, #infinite-handle span button:hover{color:' . $color . '}' . "\n";
				  $custom_css .= '.woocommerce #respond input#submit.alt:hover,a.comment-reply-link:hover, .woocommerce a.button.alt:hover, .woocommerce button.button.alt:hover, .woocommerce input.button.alt:hover, .woocommerce #respond input#submit:hover, .woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button.woocommerce:hover #respond input#submit.alt.disabled, .woocommerce #respond input#submit.alt.disabled:hover, .woocommerce #respond input#submit.alt:disabled, .woocommerce #respond input#submit.alt:disabled:hover, .woocommerce #respond input#submit.alt[disabled]:disabled, .woocommerce #respond input#submit.alt[disabled]:disabled:hover, .woocommerce a.button.alt.disabled, .woocommerce a.button.alt.disabled:hover, .woocommerce a.button.alt:disabled, .woocommerce a.button.alt:disabled:hover, .woocommerce a.button.alt[disabled]:disabled, .woocommerce a.button.alt[disabled]:disabled:hover, .woocommerce button.button.alt.disabled, .woocommerce button.button.alt.disabled:hover, .woocommerce button.button.alt:disabled, .woocommerce button.button.alt:disabled:hover, .woocommerce button.button.alt[disabled]:disabled, .woocommerce button.button.alt[disabled]:disabled:hover, .woocommerce input.button.alt.disabled, .woocommerce input.button.alt.disabled:hover, .woocommerce input.button.alt:disabled, .woocommerce input.button.alt:disabled:hover, .woocommerce input.button.alt[disabled]:disabled, .woocommerce input.button.alt[disabled]:disabled:hover, .woocommerce #respond input#submit:hover, .woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button:hover:hover{color:' . $color . '}' . "\n";
				  break;
				case 'color_basic_button_background':
				  $custom_css .= '#infinite-handle span,.search-box > a,a.button,a.links-btn::after,.search-form .search-submit,.woocommerce #respond input#submit.alt, .woocommerce a.button.alt, .woocommerce button.button.alt, .woocommerce input.button.alt, .woocommerce #respond input#submit, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button{background-color:' . $color . '}' . "\n";
				  $custom_css .= 'a.cta-button-primary,.comment-reply-link,button, input[type="button"], input[type="reset"], input[type="submit"],#infinite-handle span button{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_basic_button_background_hover':
				  $custom_css .= '#infinite-handle span:hover,.search-box > a:hover,a.button:hover,a.links-btn:hover::after,.search-form .search-submit:hover,a.cta-button-primary:hover,a.comment-reply-link:hover,.comment-reply-link:hover,button:hover, input[type="button"]:hover, input[type="reset"]:hover, input[type="submit"]:hover,#infinite-handle span button{background-color:' . $color . '}' . "\n";
				  $custom_css .= '.woocommerce #respond input#submit.alt:hover, .woocommerce a.button.alt:hover, .woocommerce button.button.alt:hover, .woocommerce input.button.alt:hover, .woocommerce #respond input#submit:hover, .woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button.woocommerce:hover #respond input#submit.alt.disabled, .woocommerce #respond input#submit.alt.disabled:hover, .woocommerce #respond input#submit.alt:disabled, .woocommerce #respond input#submit.alt:disabled:hover, .woocommerce #respond input#submit.alt[disabled]:disabled, .woocommerce #respond input#submit.alt[disabled]:disabled:hover, .woocommerce a.button.alt.disabled, .woocommerce a.button.alt.disabled:hover, .woocommerce a.button.alt:disabled, .woocommerce a.button.alt:disabled:hover, .woocommerce a.button.alt[disabled]:disabled, .woocommerce a.button.alt[disabled]:disabled:hover, .woocommerce button.button.alt.disabled, .woocommerce button.button.alt.disabled:hover, .woocommerce button.button.alt:disabled, .woocommerce button.button.alt:disabled:hover, .woocommerce button.button.alt[disabled]:disabled, .woocommerce button.button.alt[disabled]:disabled:hover, .woocommerce input.button.alt.disabled, .woocommerce input.button.alt.disabled:hover, .woocommerce input.button.alt:disabled, .woocommerce input.button.alt:disabled:hover, .woocommerce input.button.alt[disabled]:disabled, .woocommerce input.button.alt[disabled]:disabled:hover, .woocommerce #respond input#submit:hover, .woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button:hover{background-color:' . $color . '}' . "\n";
				  break;

				// Header.
				case 'color_header_background':
				  $custom_css .= '#masthead {background-color:' . $color . '}' . "\n";
				  break;
				case 'color_header_title':
				  $custom_css .= '.site-title > a{color:' . $color . '}' . "\n";
		        break;
				case 'color_header_title_hover':
				  $custom_css .= '.site-title > a:hover{color:' . $color . '}' . "\n";
				  break;
				case 'color_header_tagline':
				  $custom_css .= '.site-description{color:' . $color . '}' . "\n";
				  break;

				// Featured Content.
				case 'color_featured_content_background':
				  $custom_css .= '#featured-content{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_featured_content_title_link':
				  $custom_css .= '#featured-content .entry-title a ,#featured-content .entry-title{color:' . $color . '}' . "\n";
				  break;
				case 'color_featured_content_title_link_hover':
				  $custom_css .= '#featured-content .entry-title a:hover{color:' . $color . '}' . "\n";
				  break;
				case 'color_featured_content_text':
				  $custom_css .= '#featured-content {color:' . $color . '}' . "\n";
				  break;

				// Content.
				case 'color_content_background':
				  $custom_css .= '#content{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_content_title':
				  $custom_css .= '#content .entry-title{color:' . $color . '}' . "\n";
				  break;
				case 'color_content_text':
				  $custom_css .= '#content {color:' . $color . '}' . "\n";
				  break;
				case 'color_content_link':
				  $custom_css .= '#content a{color:' . $color . '}' . "\n";
				  break;
				case 'color_content_link_hover':
				  $custom_css .= '#content  a:hover{color:' . $color . '}' . "\n";
				  break;
				case 'color_content_meta_link':
				  $custom_css .= '#content .entry-meta > span a,#content .entry-footer > span a{color:' . $color . '}' . "\n";
				  break;
				case 'color_content_meta_link_hover':
				  $custom_css .= '#content .entry-meta > span a:hover,#content  .entry-footer > span a:hover{color:' . $color . '}' . "\n";
				  break;
				case 'color_content_meta_icon':
				  $custom_css .= '#content .entry-meta > span::before,#content  .entry-footer > span::before{color:' . $color . '}' . "\n";
				  break;

				// Slider.
				case 'color_slider_title_background':
				  $custom_css .= '#main-slider .cycle-caption h3{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_slider_text_background':
				  $custom_css .= '#main-slider .cycle-caption p{background-color:' . $color . '}' . "\n";
				break;
				case 'color_slider_caption_text':
				  $custom_css .= '#main-slider {color:' . $color . '}' . "\n";
				  break;
				case 'color_slider_caption_link':
				  $custom_css .= '#main-slider a{color:' . $color . '}' . "\n";
				  break;
				case 'color_slider_caption_link_hover':
				  $custom_css .= '#main-slider  a:hover{color:' . $color . '}' . "\n";
				  break;
				case 'color_slider_icon':
				  $custom_css .= '#main-slider .cycle-prev, #main-slider .cycle-next{color:' . $color . '}' . "\n";
				  break;
				case 'color_slider_icon_hover':
				  $custom_css .= '#main-slider .cycle-prev:hover::after, #main-slider .cycle-next:hover::after{color:' . $color . '}' . "\n";
				  break;
				case 'color_slider_icon_background':
				  $custom_css .= '#main-slider .cycle-prev::after, #main-slider .cycle-next::after{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_slider_icon_background_hover':
				  $custom_css .= '#main-slider .cycle-prev:hover::after, #main-slider .cycle-next:hover::after{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_slider_pager':
				  $custom_css .= '#main-slider .pager-box{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_slider_pager_active':
				  $custom_css .= '#main-slider .pager-box:hover,#main-slider .pager-box.cycle-pager-active{background-color:' . $color . '}' . "\n";
				  break;

				// Sidebar.
				case 'color_sidebar_title':
				  $custom_css .= '.sidebar .widget-title{color:' . $color . '}' . "\n";
				  break;
				case 'color_sidebar_text':
				  $custom_css .= '.sidebar{color:' . $color . '}' . "\n";
				  break;
				case 'color_sidebar_link':
				  $custom_css .= '.sidebar a{color:' . $color . '}' . "\n";
				  $custom_css .= '.sidebar .widget{border-bottom-color:' . $color . '}' . "\n";

				  break;
				case 'color_sidebar_link_hover':
				  $custom_css .= '.sidebar  a:hover{color:' . $color . '}' . "\n";
				  break;
				case 'color_sidebar_list_icon':
				  $custom_css .= '.sidebar ul li::before{color:' . $color . '}' . "\n";
				  break;


				// Home Page Widgets.
				case 'color_home_widgets_area_background':
				  $custom_css .= '#sidebar-front-page-widget-area{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_home_widgets_title':
				  $custom_css .= '#sidebar-front-page-widget-area .widget-title span{color:' . $color . '}' . "\n";
				  break;
				 case 'color_home_widgets_title_background':
				  $custom_css .= '#sidebar-front-page-widget-area .widget-title span {background-color:' . $color . '}' . "\n";
				  break;
				case 'color_home_widgets_text':
				  $custom_css .= '#sidebar-front-page-widget-area {color:' . $color . '}' . "\n";
				  break;
				case 'color_home_widgets_link':
				  $custom_css .= '#sidebar-front-page-widget-area a{color:' . $color . '}' . "\n";
				  break;
				case 'color_home_widgets_link_hover':
				  $custom_css .= '#sidebar-front-page-widget-area a:hover{color:' . $color . '}' . "\n";
				  break;

				// Footer area.
				case 'color_footer_area_background':
				  $custom_css .= '#colophon{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_footer_area_text':
				  $custom_css .= '#colophon{color:' . $color . '}' . "\n";
				  break;
				case 'color_footer_area_link':
				  $custom_css .= '#colophon a{color:' . $color . '}' . "\n";
				  break;
				case 'color_footer_area_link_hover':
				  $custom_css .= '#colophon a:hover{color:' . $color . '}' . "\n";
				  break;

				// Go To Top.
			    case 'color_goto_top_icon':
				  $custom_css .= '#btn-scrollup i.fa{color:' . $color . '}' . "\n";
				  break;
				case 'color_goto_top_icon_hover':
				  $custom_css .= '#btn-scrollup i.fa:hover{color:' . $color . '}' . "\n";
				  break;
				case 'color_goto_top_background':
				  $custom_css .= '#btn-scrollup{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_goto_top_background_hover':
				  $custom_css .= '#btn-scrollup:hover{background-color:' . $color . '}' . "\n";
				  break;


				// Pagination.
				case 'color_pagination_link':
				  $custom_css .= '.nav-links .nav-previous a,.nav-links .nav-next a,.comment-navigation .nav-next::after, .posts-navigation .nav-next::after, .post-navigation .nav-next::after,.comment-navigation .nav-previous::before, .posts-navigation .nav-previous::before, .post-navigation .nav-previous::before,.nav-links a,.nav-links .nav-previous a,.pagination .nav-links > a, .pagination .nav-links > span, .wp-pagenavi a, .wp-pagenavi span.navigation .nav-links > a{color:' . $color . '}' . "\n";
				  break;
				case 'color_pagination_link_hover':
				  $custom_css .= '.nav-links .nav-previous a:hover,.nav-links .nav-next a:hover,.comment-navigation .nav-next:hover::after, .posts-navigation .nav-next:hover::after, .post-navigation .nav-next:hover::after,.comment-navigation .nav-previous:hover::before, .posts-navigation .nav-previous:hover::before, .post-navigation .nav-previous:hover::before,.nav-links a:hover,.nav-links .nav-previous a.navigation .nav-links > a:hover,.pagination .nav-links > span.current, .pagination .nav-links > a:hover, .wp-pagenavi span.current{color:' . $color . '}' . "\n";
				  break;
				case 'color_pagination_link_background':
				  $custom_css .= '.nav-links .nav-previous a,.nav-links .nav-next a,.comment-navigation .nav-next, .posts-navigation .nav-next, .post-navigation .nav-next.pagination .nav-links > a, .pagination .nav-links > span, .wp-pagenavi a, .wp-pagenavi span{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_pagination_link_background_hover':
				  $custom_css .= '.nav-links .nav-previous a:hover,.nav-links .nav-next a:hover,.comment-navigation .nav-previous:hover, .posts-navigation .nav-previous:hover, .post-navigation .nav-previous:hover, .comment-navigation .nav-next:hover, .posts-navigation .nav-next:hover, .post-navigation .nav-next:hover,.pagination .nav-links > span.current, .pagination .nav-links > a:hover, .wp-pagenavi span.current, .wp-pagenavi a:hover{background-color:' . $color . '}' . "\n";
				  break;

				// Breadcrumb.
				case 'color_breadcrumb_background':
				  $custom_css .= '#breadcrumb{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_breadcrumb_link':
				  $custom_css .= '#crumbs a,#breadcrumb a{color:' . $color . '}' . "\n";
				  break;
				case 'color_breadcrumb_link_hover':
				  $custom_css .= '#crumbs a:hover,#breadcrumb a:hover{color:' . $color . '}' . "\n";
				  break;
				case 'color_breadcrumb_text':
				  $custom_css .= '#breadcrumb{color:' . $color . '}' . "\n";
				  break;

				// Footer Widgets.
				case 'color_footer_widgets_background':
				  $custom_css .= '#footer-widgets{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_footer_widgets_title':
				  $custom_css .= '#footer-widgets .widget-title{color:' . $color . '}' . "\n";
				  break;
				case 'color_footer_widgets_text':
				  $custom_css .= '#footer-widgets {color:' . $color . '}' . "\n";
				  break;
				case 'color_footer_widgets_link':
				  $custom_css .= '#footer-widgets a{color:' . $color . '}' . "\n";
				  $custom_css .= '#footer-widgets h3.widget-title::after{background-color:' . $color . '}' . "\n";
			      $custom_css .= '#footer-widgets  break;{border-color:' . $color . '}' . "\n";
				break;
				
				case 'color_footer_widgets_link_hover':
				  $custom_css .= '#footer-widgets a:hover{color:' . $color . '}' . "\n";
				  break;
				case 'color_footer_widgets_list_icon':
				  $custom_css .= '#footer-widgets ul li::before{color:' . $color . '}' . "\n";
				  break;


				// Primary Menu.
				case 'color_primary_menu_main_background':
				  $custom_css .= '#main-nav,#main-nav ul ul{background-color:' . $color . '}' . "\n";
				   $custom_css .= '#main-nav{border-color:' . $color . '}' . "\n";
				  break;
				case 'color_primary_menu_link':
				  $custom_css .= '#main-nav ul li a,.dropdown-toggle::after{color:' . $color . '}' . "\n";
				  break;
				case 'color_primary_menu_link_hover':
				  $custom_css .= '#main-nav ul li a:hover,#main-nav li.current-menu-item > a,
				  #main-nav li.current_page_item > a,#main-nav ul li:hover > a{color:' . $color . '}' . "\n";
				  break;
				case 'color_primary_menu_link_background':
				  $custom_css .= '#main-nav ul li a{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_primary_menu_link_background_hover':
				  $custom_css .= '#main-nav ul li a:hover,#main-nav ul li:hover > a, #main-nav li.current-menu-item > a,
				  #main-nav li.current_page_item > a{background-color:' . $color . '}' . "\n";
				break;

				// Specific widget CTA

				case 'color_cta_widget_background':
				  $custom_css .= '.trade_line_widget_call_to_action{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_cta_widget_title':
				  $custom_css .= '.trade_line_widget_call_to_action .widget-title span,#sidebar-front-page-widget-area .trade_line_widget_call_to_action .widget-title span{color:' . $color . '}' . "\n";
				  break;
				case 'color_cta_widget_text':
				  $custom_css .= '#sidebar-front-page-widget-area .trade_line_widget_call_to_action, .trade_line_widget_call_to_action{color:' . $color . '}' . "\n";
				  break;
				case 'color_cta_widget_border':
				  $custom_css .= '.trade_line_widget_call_to_action .trade_line_widget_call_to_action,.trade_line_widget_call_to_action{border-color:' . $color . '}' . "\n";
				  break;
				case 'color_cta_widget_button_background_color':
				  $custom_css .= '.call-to-action-buttons a.cta-button{background-color:' . $color . '}' . "\n";
				  break;
				 case 'color_cta_widget_button_color':
				  $custom_css .= '.call-to-action-buttons a.cta-button{color:' . $color . '}' . "\n";
				  break;
				case 'color_cta_widget_button_background_hover':
				  $custom_css .= '.call-to-action-buttons a.cta-button:hover{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_cta_widget_button_hover_color':
				  $custom_css .= '.call-to-action-buttons a.cta-button:hover{color:' . $color . '}' . "\n";
				  break;

				// Specific widget Latest News Widget
				case 'color_latest_news_main_widget_title':
				  $custom_css .= '#sidebar-front-page-widget-area .trade_line_widget_latest_news .widget-title span{color:' . $color . '}' . "\n";
				  break;
				case 'color_latest_news_widget_title_background':
				  $custom_css .= '#sidebar-front-page-widget-area .trade_line_widget_latest_news .widget-title span{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_latest_news_widget_title':
				  $custom_css .= '#sidebar-front-page-widget-area .latest-news-text-wrap .latest-news-title a,.latest-news-text-wrap .latest-news-title a{color:' . $color . '}' . "\n";
				  break;
				case 'color_latest_news_widget_title_hover':
				  $custom_css .= '#sidebar-front-page-widget-area .latest-news-text-wrap .latest-news-title a:hover,.latest-news-text-wrap .latest-news-title a:hover{color:' . $color . '}' . "\n";
				  break;
				case 'color_latest_news_widget_text':
				  $custom_css .= '#sidebar-front-page-widget-area .latest-news-text-wrap, .latest-news-text-wrap{color:' . $color . '}' . "\n";
				  break;
				case 'color_latest_news_widget_link':
				  $custom_css .= '#sidebar-front-page-widget-area .latest-news-text-wrap a,.latest-news-text-wrap a{color:' . $color . '}' . "\n";
				  break;
				case 'color_latest_news_widget_link_hover':
				  $custom_css .= '#sidebar-front-page-widget-area .latest-news-text-wrap a:hover, .latest-news-text-wrap a:hover{color:' . $color . '}' . "\n";
				  $custom_css .= '.latest-news-text-wrap{border-color:' . $color . '}' . "\n";
				  break;
			  	case 'color_latest_news_widget_content_background':
				  $custom_css .= '.latest-news-text-wrap{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_latest_news_widget_border':
				  $custom_css .= '.latest-news-text-wrap{border-color:' . $color . '}' . "\n";
				  break;

				// Specific widget Portfolio Widget.
				case 'color_portfolio_main_widget_title':
				  $custom_css .= '#sidebar-front-page-widget-area .trade_line_widget_portfolio .widget-title span{color:' . $color . '}' . "\n";
				  break;
				case 'color_portfolio_widget_title_background':
				  $custom_css .= '#sidebar-front-page-widget-area .trade_line_widget_portfolio .widget-title span{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_portfolio_widget_title':
				  $custom_css .= '#sidebar-front-page-widget-area .portfolio-main-wrapper .portfolio-item-title a,.portfolio-main-wrapper .portfolio-item-title a{color:' . $color . '}' . "\n";
				  break;
				case 'color_portfolio_widget_title_hover':
				  $custom_css .= '#sidebar-front-page-widget-area .portfolio-main-wrapper .portfolio-item-title a:hover,.portfolio-main-wrapper .portfolio-item-title a:hover{color:' . $color . '}' . "\n";
				break;
				case 'color_portfolio_widget_tab':
				  $custom_css .= '#sidebar-front-page-widget-area .portfolio-main-wrapper .portfolio-filter a,.portfolio-main-wrapper .portfolio-filter a{color:' . $color . '}' . "\n";
				  break;
				case 'color_portfolio_widget_tab_color_hover':
				  $custom_css .= '#sidebar-front-page-widget-area .portfolio-main-wrapper .portfolio-filter a:hover,.portfolio-main-wrapper .portfolio-filter a:hover,#sidebar-front-page-widget-area .portfolio-main-wrapper .portfolio-filter a.current,.portfolio-main-wrapper .portfolio-filter a.current{color:' . $color . '}' . "\n";
				  break;

				// Specific widget Testimonial .
				case 'color_testimonial_main_widget_title':
				  $custom_css .= '#sidebar-front-page-widget-area .trade_line_widget_testimonials .widget-title span{color:' . $color . '}' . "\n";
				  break;
				case 'color_testimonial_widget_title_background':
				  $custom_css .= '#sidebar-front-page-widget-area .trade_line_widget_testimonials .widget-title span{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_testimonial_widget_content':
				  $custom_css .= '#sidebar-front-page-widget-area .trade_line_widget_testimonials{color:' . $color . '}' . "\n";
				  break;
				case 'color_testimonial_widget_arrow':
				  $custom_css .= '.trade_line_widget_testimonials .cycle-prev::after, .trade_line_widget_testimonials .cycle-next::after{color:' . $color . '}' . "\n";
				  $custom_css .= '.trade_line_widget_testimonials .testimonial-thumb img{box-shadow:-4px -8px 0 ' . $color . '}' . "\n";

				  break;
				case 'color_testimonial_widget_arrow_hover':
				  $custom_css .= '.trade_line_widget_testimonials .cycle-prev:hover::after, .trade_line_widget_testimonials .cycle-next:hover::after{color:' . $color . '}' . "\n";
				  break;
				case 'color_testimonial_widget_author':
				  $custom_css .= '.trade_line_widget_testimonials .testimonial-title{color:' . $color . '}' . "\n";
				  break;
				case 'color_testimonial_pager':
				  $custom_css .= '.trade_line_widget_testimonials .cycle-pager > span {background-color:' . $color . '}' . "\n";
				  break;
				case 'color_testimonial_widget_pager_active':
				  $custom_css .= '.trade_line_widget_testimonials .cycle-pager > span.cycle-pager-active,.trade_line_widget_testimonials .cycle-pager > span:hover {background-color:' . $color . '}' . "\n";
				  break;

				// Specific widget Team  .

				case 'color_team_main_widget_title':
				  $custom_css .= '#sidebar-front-page-widget-area .trade_line_widget_teams .widget-title span{color:' . $color . '}' . "\n";
				  break;
				case 'color_team_widget_title_background':
				  $custom_css .= '#sidebar-front-page-widget-area .trade_line_widget_teams .widget-title span{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_team_widget_title':
				  $custom_css .= '#sidebar-front-page-widget-area .trade_line_widget_teams .our-team-title a,.trade_line_widget_teams .our-team-title a{color:' . $color . '}' . "\n";
				  break;
				case 'color_team_widget_title_hover':
				  $custom_css .= '#sidebar-front-page-widget-area .trade_line_widget_teams .our-team-title a:hover,.trade_line_widget_teams .our-team-title a:hover{color:' . $color . '}' . "\n";
				  break;
				case 'color_team_widget_sub_title':
				  $custom_css .= '.trade_line_widget_teams .team-designation{color:' . $color . '}' . "\n";
				  break;
				case 'color_team_widget_title_background_color':
				  $custom_css .= '.our-team-text-wrap{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_team_widget_content_text':
				  $custom_css .= '.our-team-summary{color:' . $color . '}' . "\n";
				  break;
				case 'color_team_widget_content_background_color':
				  $custom_css .= '.our-team-summary{background-color:' . $color . '}' . "\n";
				  break;

				// Specific widget Service .
				case 'color_service_main_widget_title':
				  $custom_css .= '#sidebar-front-page-widget-area .trade_line_widget_services .widget-title span{color:' . $color . '}' . "\n";
				  break;
				case 'color_service_widget_title_background':
				  $custom_css .= '#sidebar-front-page-widget-area .trade_line_widget_services .widget-title span{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_service_widget_icon':
				  $custom_css .= '#sidebar-front-page-widget-area .service-block-item i{color:' . $color . '}' . "\n";
				  break;
				case 'color_service_widget_icon_background':
				  $custom_css .= '.trade_line_widget_services .service-block-item i{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_service_widget_title':
				  $custom_css .= '#sidebar-front-page-widget-area .trade_line_widget_services .service-block-item .service-item-title a,.trade_line_widget_services .service-block-item .service-item-title a{color:' . $color . '}' . "\n";
				  break;
				case 'color_service_widget_title_hover':
				  $custom_css .= '#sidebar-front-page-widget-area .trade_line_widget_services .service-block-item .service-item-title a:hover,.trade_line_widget_services .service-block-item .service-item-title a:hover{color:' . $color . '}' . "\n";
				  break;
				case 'color_service_widget_text':
				  $custom_css .= '.trade_line_widget_services .service-block-item,.trade_line_widget_services .service-block-item:hover {color:' . $color . '}' . "\n";
				  break;
				case 'color_service_widget_link':
				  $custom_css .= '#sidebar-front-page-widget-area .service-block-item a,.service-block-item a{color:' . $color . '}' . "\n";
				  break;
				case 'color_service_widget_link_hover':
				  $custom_css .= '#sidebar-front-page-widget-area .service-block-item a:hover,.service-block-item a:hover{color:' . $color . '}' . "\n";
				  break;
				case 'color_service_widget_item_hover_background':
				  $custom_css .= '.trade_line_widget_services .service-block-item:hover{background-color:' . $color . '}' . "\n";
				  break;

			  default:
			    break;

			}

		}

		// Render style.
		if ( ! empty( $custom_css ) ) {
		  echo '<style type="text/css">';
		  echo $custom_css;
		  echo '</style>';
		}

	}

endif;

add_action( 'trade_line_action_theme_custom_css', 'trade_line_add_theme_custom_color_css', 25 );
